@@ -6,11 +6,16 @@
  */
 #ifndef SPICE_STREAMING_AGENT_FRAME_CAPTURE_HPP
 #define SPICE_STREAMING_AGENT_FRAME_CAPTURE_HPP
+
+#include <cstdint>
 #include <cstdio>
+#include <string>
+#include <vector>
 
 #include <spice/enums.h>
 
-namespace SpiceStreamingAgent {
+namespace spice {
+namespace streaming_agent {
 
 struct FrameSize
 {
@@ -28,35 +33,44 @@ struct FrameInfo
     bool stream_start;
 };
 
+struct DeviceDisplayInfo
+{
+    uint32_t stream_id;
+    std::string device_address;
+    uint32_t device_display_id;
+};
+
 /*!
  * Pure base class implementing the frame capture
  */
 class FrameCapture
 {
 public:
-    virtual ~FrameCapture()=default;
+    virtual ~FrameCapture() = default;
 
     /*! Grab a frame
      * This function will wait for next frame.
      * Capture is started if needed.
      */
-    virtual FrameInfo CaptureFrame()=0;
+    virtual FrameInfo CaptureFrame() = 0;
 
     /*! Reset capturing
      * This will reset to beginning state
      */
-    virtual void Reset()=0;
+    virtual void Reset() = 0;
 
     /*!
      * Get video codec used to encode last frame
      */
-    virtual SpiceVideoCodecType VideoCodecType() const=0;
+    virtual SpiceVideoCodecType VideoCodecType() const = 0;
+
+    virtual std::vector<DeviceDisplayInfo> get_device_display_info() const = 0;
 protected:
-    FrameCapture()=default;
-    FrameCapture(const FrameCapture&)=delete;
-    void operator=(const FrameCapture&)=delete;
+    FrameCapture() = default;
+    FrameCapture(const FrameCapture&) = delete;
+    void operator=(const FrameCapture&) = delete;
 };
 
-}
+}} // namespace spice::streaming_agent
 
 #endif // SPICE_STREAMING_AGENT_FRAME_CAPTURE_HPP
