@@ -7,10 +7,14 @@
 #define SPICE_STREAMING_AGENT_CONCRETE_AGENT_HPP
 
 #include <vector>
+#include <set>
 #include <memory>
 #include <spice-streaming-agent/plugin.hpp>
 
-namespace SpiceStreamingAgent {
+namespace spice {
+namespace streaming_agent {
+
+class FrameLog;
 
 struct ConcreteConfigureOption: ConfigureOption
 {
@@ -24,23 +28,22 @@ struct ConcreteConfigureOption: ConfigureOption
 class ConcreteAgent final : public Agent
 {
 public:
-    ConcreteAgent();
-    unsigned Version() const override {
-        return PluginVersion;
-    }
-    void Register(Plugin& plugin) override;
+    ConcreteAgent(const std::vector<ConcreteConfigureOption> &options,
+                  FrameLog *logger=nullptr);
+    void Register(const std::shared_ptr<Plugin>& plugin) override;
     const ConfigureOption* Options() const override;
-    void LoadPlugins(const char *directory);
-    // pointer must remain valid
-    void AddOption(const char *name, const char *value);
-    FrameCapture *GetBestFrameCapture();
-    bool PluginVersionIsCompatible(unsigned pluginVersion) const override;
+    void LoadPlugins(const std::string &directory);
+    FrameCapture *GetBestFrameCapture(const std::set<SpiceVideoCodecType>& codecs);
+    __attribute__ ((format (printf, 2, 3)))
+    void LogStat(const char* format, ...) override;
 private:
-    void LoadPlugin(const char *plugin_filename);
+    bool PluginVersionIsCompatible(unsigned pluginVersion) const;
+    void LoadPlugin(const std::string &plugin_filename);
     std::vector<std::shared_ptr<Plugin>> plugins;
     std::vector<ConcreteConfigureOption> options;
+    FrameLog *const logger = nullptr;
 };
 
-}
+}} // namespace spice::streaming_agent
 
 #endif // SPICE_STREAMING_AGENT_CONCRETE_AGENT_HPP
